侧耳倾听 (豆瓣)
Description: 侧耳倾听电影简介和剧情介绍,侧耳倾听影评、图片、预告片、影讯、论坛、在线购票
Keywords: 侧耳倾听,耳をすませば,侧耳倾听影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.126豆瓣电影Top250

# 侧耳倾听 耳をすませば (1995)

导演: 近藤喜文
编剧: 宫崎骏 / 柊葵
主演: 本名阳子 / 小林桂树 / 高山南 / 高桥一生 / 山下容莉枝 / 室井滋 / 露口茂 / 饭冢雅弓
类型: 剧情 / 爱情 / 动画
制片国家/地区: 日本
语言: 日语 / 英语
上映日期: 1995-07-15(日本)
片长: 111分钟
又名: 心之谷(台) / 梦幻街少女(港) / Whisper of the Heart / Mimi wo sumaseba
IMDb: tt0113824
豆瓣评分
引用
8.9
438050人评价
5星
55.9%
4星
35.2%
3星
8.3%
2星
0.5%
1星
0.1%
好于 97% 动画片
好于 98% 爱情片
想看 看过
评价:
推荐

## 侧耳倾听的剧情简介 · · · · · ·

正在读初三的月岛雯是一个喜欢看书的女孩，她每次都能在借书卡上看到一个叫天泽圣司名字，因此她对这个人充满了好奇。 雯一直喜欢写诗，有一天她跟好友夕子在讨论写诗的事，夕子告诉雯自己收到了情书，但事实上夕子已有了喜欢的人。更没有想到的是，夕子喜欢的杉村喜欢的是雯，雯一时间感到十分困惑。 雯无意中来到了一个小店，原来店主是圣司的爷爷。认识了圣司之后，听到了圣司对自己理想的追求之后，也激发了雯对自己理想的追求之念。当圣司离开了到意大利学习做小提琴时，雯决定要专心写作。当雯完成了作品之后，她发现原来自己高估了自己，就这样她选择继续考高中，这时她非常想念圣司。 一天凌晨，她站到窗边，突然看到了一个熟悉的身影…… ©豆瓣

## 侧耳倾听的演职员 · · · · · · ( 全部 16 )

- 近藤喜文 导演
- 本名阳子 配 月岛雯
- 小林桂树 配 西司朗
- 高山南 配 高坂老师
- 高桥一生 配 天泽圣司
- 山下容莉枝 配 月岛汐子

## 侧耳倾听的图片 ······ ( 添加视频评论 | 图片1257 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  天空之城

  幽灵公主

  风之谷

  哈尔的移动城堡

  魔女宅急便

  红猪

  猫的报恩

  岁月的童话

  起风了

  大闹天宫

我要写短评

## 侧耳倾听的短评 · · · · · · ( 全部 99490 条 )

热门 / 最新 / 好友

### 1801 有用 米粒 看过 2014-11-04 14:03:26

原来图书卡寻人是这里来的呀。他们的城市是立体的，真漂亮，恋爱要翻山越岭才行。电影几乎集结了所有少女时代的美好回忆，完美、理想到失真，像一个斑斓的气泡，害怕一伸手就会破碎… 乱糟糟的书桌，伸手摸来摸去就是摸不到台灯开关，生活中的细节被它完整地还原，似曾相识，却不属于我…

### 2621 有用 蚂蚁没问题 看过 2009-03-30 12:33:33

美则美矣 但是看着两个初中生这样子的深情 最后还说出你将来嫁给我这种话 还是觉得有点怪怪的

### 2137 有用 眠去 看过 2008-04-20 08:07:40

为了让我的名字早点出现在借书卡上，我看了好多书。。。

### 1430 有用 野次馬 看过 2012-07-11 10:39:03

这是一个我早已错过的故事，我没有在十五岁看到它，我早已进入了不用借书卡的年代。现实中，只有我一个人与图书馆天荒地老。即便如此，我还是感谢它赐予我的全部勇气。|一五年夏去了多摩市。走在コンクリートロード上，山雨欲来，穿过长长长长的階段，从来没有觉得他们如此真实过。

### 1349 有用 昏金暗玉 看过 2010-05-12 11:16:01

最动人的一幕出现在爷爷拿着月岛刚完成的稚嫩的小说，对她说：太棒了，真是太棒了。在才华刚刚起步的日子里，有一个人能完全诚挚地赞美，比什么都好，它不会令人骄傲，相反会让人更看清自己。

> 更多短评 99490条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 侧耳倾听的影评 · · · · · · ( 全部 1673 条 )

热门 / 最新 / 好友
水湄物语 2007-10-11 09:59:07

## 为了让我的名字早点出现在借书卡上，我看了好多书

本来我以为我已经是很标准的宫崎骏迷了，他大多数的片子我都看过3遍以上，所以当看到一部我没看过的宫片时，居然对自己产生一点愤怒。嘻嘻。 很小的时候看过一本“罗兰语录”，那是台湾当时很流行的广播节目主持人，曾经有一篇写道“要让自己为了爱，变成一只开屏的孔雀”。大... (展开)
2443 183 412回应 收起
琴 酒 2009-06-26 10:24:41

## 再会吧，乡间路。

看完侧耳倾听的晚上，在反复把主题曲听了四五遍之后，我觉得心里有什么东西被放下了。 这半年来在心里郁结的留恋和踟蹰，不舍和怯懦，以及那一份说不清道不明，因将要离开而夜夜叨扰着我的乡愁，好像终于寻到了一个安放的角落。又像是历经沧桑后回到了真正的青春年华，不用想着... (展开)
1190 34 92回应 收起
老常 2008-11-12 13:18:31

## 是神让我在这样的季节看到“侧耳倾听”

这篇影评可能有剧透

电脑上的字幕已经出来了，我还是不忍关上荧屏，不忍停播那首日语的Country Road。这部电影没有让我落泪，但要说泪珠子闪啊闪的是一点也不过分的。 两个月前，我到了美国；两个月后，我在落魄中看到了它。从第一个镜头，第一个背景音乐的音符，我就觉得这是一部专门为我这样的人... (展开)
849 30 166回应 收起
已注销 2007-06-07 13:28:25

## 我们，爱

《梦幻街少女》。也译作《侧耳倾听》。美好而又安静的恋爱故事。 我们不是没有遇上过奇迹，只是我们没有足够的好奇心。 我们不会尾随一只在电车上遇见的猫咪穿过长长的街巷，所以我们也就无法遇上那样的一家店，有木马，有男爵猫，有仙子和国王相爱的大钟。 所以我们也不会有英... (展开)
478 19 70回应 收起
Totoro 2012-11-28 10:36:36

## 侧耳倾听

这篇影评可能有剧透

（一） 不知观众在看这部片子时是否注意到几个细节，在这里，借着这次机会，我想顺便指出来。 第一个细节便是在片子的开头，女主角月岛雯在晚上帮母亲去超市购买一瓶牛奶时，拿了店员给她的塑胶袋，回到家时遭到母亲的抱怨。 “只是买一瓶牛奶嘛，怎么还要用塑胶袋呢。” “人... (展开)
719 4 50回应 收起
熱風 2009-10-27 21:31:00

## 怀念近藤喜文

做动画确实是一件累人的事，做高质量的动画更是要人的命。一部超过120分钟的剧场佳作，作画枚数往往以数万乃至十数万计。在动画制作进行时，上至监督，下至原画、动画，无不如踏进地狱之门，接受永无止境的折磨。宫崎骏和押井守都在媒体上或多或少地表达过作业强度大的... (展开)
400 8 32回应 收起
满[已注销] 2006-08-29 11:48:01

## 我曾爱过一个男孩

稀薄的晨雾里。冬日的冷空气里。 骑着单车，载着心爱的女孩，飞奔。 裹着他的外套，却决心不要做他的负担。 静静地一起等待日出。 朝阳初升，彩霞满天。 终于。终于。迟疑地说出口：我喜欢你！虽然，虽然不是现在，但是我一定会成为一流的小提琴制造者，那时候可以嫁给我吗？ ... (展开)
255 17 54回应 收起
南吴居士 2008-11-16 17:00:54

## 那无法企及的乐器重奏的几分钟

这篇影评可能有剧透

雫：“厉害，能做出这样的（小提琴）！好像是魔法。” 聖司：“你也真是，丢脸的话也说得出口。” 雫：“没关系，我那么觉得就是了。” 聖司：“那种程度的东西谁都会做。还完全不行。” 这段对话说得很轻巧，在整部影片中却是最有分量的。这段对话之后紧接着的一段短短几分钟... (展开)
194 16 20回应 收起
多喝热水 2015-10-19 22:56:51

## 真正的爱，是让我们成为最好的自己

好奇是只狡猾的猫，带着你走过大街小巷，穿过闹市，走出死角，你以为自己被捉弄了，却意外发现了更好的自己。 阿雯是个开朗的女初中生，读书狂。普通却又闪闪发光，自信且元气满满。看到她家里不大的地方整整齐齐地堆着满满的书，就不奇怪她会如此喜欢读书。然后她偶然发现有... (展开)
122 2 10回应 收起
慕詩 2017-05-22 13:07:12

## 年少青春纯真的爱

起初接触宫崎骏先生的电影是电视上播放的天空之城，磅礴大气的音乐，充满想象力的画面设计，年少的我疯狂的在网上搜索观看他的作品。 当时是一天到晚泡在房间里连看的状态，侧耳倾听这部正好是卡在中间看的，记得看完开心又兴奋的给朋友群发了信息，内容是被鼓舞被激励觉得满血... (展开)
42 1回应 收起

> 更多影评 1673篇

添加新讨论

## 讨论区 · · · · · ·

日本的中学是公开的允许谈恋爱的吗 | 来自甜刺猬 | 15 回应 | 2022-11-22 00:28:34
一个细节 有人坚持看完片尾了吗？ | 来自1w. | 29 回应 | 2022-11-19 00:07:09
没有人讨论chilledcow直播封面吗哈哈哈 | 来自badtango | 2 回应 | 2022-11-10 16:40:07
因为高桥一生配音要看这部电影 | 来自她在屋顶 | 3 回应 | 2022-11-10 16:39:05
优酷的汉语配音一股琼瑶感 | 来自非必要不增实物 | 6 回应 | 2022-11-04 15:53:23

> 去这部影片的讨论区（全部225条）

## 关于《侧耳倾听》的问题 · · · · · · ( 全部6个 )

- 有关这部动画片的名字？ 6人回答
- 片头的 take me home，country roads是谁唱的？ 1人回答

> 全部6个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【励志电影】 (影志)
- 【豆瓣高分动画长片】 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 日式青春 (沉歌)
- 治愈系动画推荐 ([己注销])

## 谁在看这部电影 · · · · · ·

- 豆友m7f7M1KPSY
  刚刚 看过
- 苍耳子散
  3分钟前 想看
- 264726162
  7分钟前 看过

650065人看过 / 235479人想看

订阅侧耳倾听的评论:
feed: rss 2.0